@@ -64,6 +64,22 @@ class CSVKitUtility(object):
         else:
             self.output_file = output_file
 
+        # Ensure SIGPIPE doesn't throw an exception
+        # Prevents [Errno 32] Broken pipe errors, e.g. when piping to 'head'
+        # To test from the shell:
+        #  python -c "for i in range(5000): print 'a,b,c'" | csvlook | head
+        # Without this fix you will see at the end:
+        #  [Errno 32] Broken pipe
+        # With this fix, there should be no error
+        # For details on Python and SIGPIPE, see http://bugs.python.org/issue1652
+        try:
+            import signal
+            signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+        except (ImportError, AttributeError):
+            #Do nothing on platforms that don't have signals or don't have SIGPIPE
+            pass
+
+
     def add_arguments(self):
         """
         Called upon initialization once the parser for common arguments has been constructed.
@@ -126,6 +142,12 @@ class CSVKitUtility(object):
             self.argparser.add_argument('-l', '--linenumbers', dest='line_numbers', action='store_true',
                                 help='Insert a column of line numbers at the front of the output. Useful when piping to grep or as a simple primary key.')
 
+        # Input/Output
+        if 'zero' not in self.override_flags:
+            self.argparser.add_argument('--zero', dest='zero_based', action='store_true',
+                            help='When interpreting or displaying column numbers, use zero-based numbering instead of the default 1-based numbering.')
+        
+
     def _extract_csv_reader_kwargs(self):
         """
         Extracts those from the command-line arguments those would should be passed through to the input CSV reader(s).
@@ -185,7 +207,27 @@ class CSVKitUtility(object):
 
         sys.excepthook = handler
 
-def match_column_identifier(column_names, c):
+    def print_column_names(self):
+        """
+        Pretty-prints the names and indices of all columns to a file-like object (usually sys.stdout).
+        """
+        f = self.args.file
+        output = self.output_file
+        try:
+            zero_based=self.args.zero_based
+        except:
+            zero_based=False
+
+        rows = CSVKitReader(f, **self.reader_kwargs)
+        column_names = rows.next()
+
+        for i, c in enumerate(column_names):
+            if not zero_based:
+                i += 1
+            output.write('%3i: %s\n' % (i, c))
+
+
+def match_column_identifier(column_names, c, zero_based=False):
     """
     Determine what column a single column id (name or index) matches in a series of column names.
     Note that integer values are *always* treated as positional identifiers. If you happen to have
@@ -195,7 +237,9 @@ def match_column_identifier(column_names, c):
         return column_names.index(c)
     else:
         try:
-            c = int(c) - 1
+            c = int(c)
+            if not zero_based:
+                c -= 1
         # Fail out if neither a column name nor an integer
         except:
             raise ColumnIdentifierError('Column identifier "%s" is neither an integer, nor a existing column\'s name.' % c)
@@ -210,7 +254,7 @@ def match_column_identifier(column_names, c):
 
     return c
 
-def parse_column_identifiers(ids, column_names):
+def parse_column_identifiers(ids, column_names,zero_based=False):
     """
     Parse a comma-separated list of column indices AND/OR names into a list of integer indices.
     Ranges of integers can be specified with two integers separated by a '-' or ':' character. Ranges of 
@@ -227,7 +271,7 @@ def parse_column_identifiers(ids, column_names):
         c = c.strip()
 
         try:
-            columns.append(match_column_identifier(column_names, c))
+            columns.append(match_column_identifier(column_names, c, zero_based))
         except ColumnIdentifierError:
             if ':' in c:
                 a,b = c.split(':',1)
@@ -250,17 +294,7 @@ def parse_column_identifiers(ids, column_names):
                 raise ColumnIdentifierError("Invalid range %s. Ranges must be two integers separated by a - or : character.")
             
             for x in range(a,b):
-                columns.append(match_column_identifier(column_names, x))
+                columns.append(match_column_identifier(column_names, x, zero_based))
 
     return columns
 
-def print_column_names(f, output, **reader_kwargs):
-    """
-    Pretty-prints the names and indices of all columns to a file-like object (usually sys.stdout).
-    """
-    rows = CSVKitReader(f, **reader_kwargs)
-    column_names = rows.next()
-
-    for i, c in enumerate(column_names):
-        output.write('%3i: %s\n' % (i + 1, c))
-
